@MYSQL@ /* This script creates a database for use with the example MySQL realm
@MYSQL@  * in /etc/tomcat/server.xml.  To execute it you should pipe this file
@MYSQL@  * to the MySQL client:
@MYSQL@  *
@MYSQL@  *  mysql -uroot -p < @DOCDIR@/MySQL-REALM.sql
@MYSQL@  *
@MYSQL@  * Note that the database server must be accepting TCP connections for
@MYSQL@  * Tomcat to be able to connect to it.  This is enabled by removing
@MYSQL@  * the 'skip-networking' option from /etc/my.cnf.
@MYSQL@  */
@PGSQL@ /* This script creates a database for use with the example PostgreSQL
@PGSQL@  * realm in /etc/tomcat/server.xml.  To execute it you should pipe
@PGSQL@  * this file to the PostgreSQL terminal:
@PGSQL@  *
@PGSQL@  *  su - postgres
@PGSQL@  *  psql template1 < @DOCDIR@/PostgreSQL-REALM.sql
@PGSQL@  *
@PGSQL@  * Note that the database server must be accepting TCP connections for
@PGSQL@  * Tomcat to be able to connect to it.  This is enabled by setting
@PGSQL@  * 'tcpip_socket=true' in /var/lib/pgsql/data/postgresql.conf and by
@PGSQL@  * adding 'host authority authority 127.0.0.1 255.255.255.255 md5' to
@PGSQL@  * /var/lib/pgsql/data/pg_hba.conf.
@PGSQL@  */

/* Create the database, named as specified by the connectionURL
 * attribute of the <Realm/> element in your server.xml.
 */
CREATE DATABASE authority;
@MYSQL@ USE authority;
@PGSQL@ \c authority

/* Create the tables, named as specified by the userTable and
 * userRoleTable attributes of your realm.  The rows are named as
 * specified the userNameCol, userCredCol and roleNameCol attributes
 * of your realm.  The rows can be CHAR or VARCHAR, and any size you
 * desire.
 */
CREATE TABLE users (
  user_name CHAR(32) NOT NULL,
  user_pass CHAR(32) NOT NULL,
  PRIMARY KEY (user_name)
);
CREATE TABLE roles (
  user_name CHAR(32) NOT NULL REFERENCES users (user_name),
  role_name CHAR(32) NOT NULL
);

/* Allow Tomcat to connect to the database server with the username
 * and password specified by the connectionName and connectionPassword
 * attributes, and allow access to all tables in the authority database.
 */
@MYSQL@ GRANT SELECT
@MYSQL@   ON users
@MYSQL@   TO authority@localhost.localdomain
@MYSQL@   IDENTIFIED BY 'PaSsW0Rd';
@MYSQL@ GRANT SELECT
@MYSQL@   ON roles
@MYSQL@   TO authority@localhost.localdomain
@MYSQL@   IDENTIFIED BY 'PaSsW0Rd';
@PGSQL@ CREATE USER authority WITH PASSWORD 'PaSsW0Rd';
@PGSQL@ GRANT SELECT ON users, roles TO authority;

/* Create an example user with no roles.
 */
INSERT INTO users VALUES ('testuser', 'testpassword');

/* Uncomment the follwing to create an example user with the 'admin'
 * and 'manager' roles.
 */
-- INSERT INTO users VALUES ('testadmin', 'testpassword');
-- INSERT INTO roles VALUES ('testadmin', 'admin');
-- INSERT INTO roles VALUES ('testadmin', 'manager');
